@@ -1,4 +1,7 @@
-from ._version import __version__, version_info
+try:
+    from ._version import __version__
+except ImportError:
+    __version__ = "unkown"
 from .generic import *
 from .helpers import *
 from .pyplot import *
